@@ -16,6 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ident "$Id: iso2022.c,v 1.13 2002/10/30 20:36:57 nalin Exp $"
 #include "config.h"
 #include <sys/types.h>
 #include <stdio.h>
@@ -52,20 +53,35 @@ struct _vte_iso2022 {
 static const struct _vte_iso2022_map _vte_iso2022_map_0[] = {
 	{ 96, 0x25c6},	/* diamond */
 	{'a', 0x2592},	/* checkerboard */
+	{'b', 0x2409},	/* HT symbol */
+	{'c', 0x240c},	/* FF symbol */
+	{'d', 0x240d},	/* CR symbol */
+	{'e', 0x240a},	/* LF symbol */
 	{'f', GDK_degree},	/* degree */
 	{'g', GDK_plusminus},	/* plus/minus */
+	{'h', 0x2424},  /* NL symbol */
+	{'i', 0x240b},  /* VT symbol */
 	{'j', 0x2518},	/* downright corner */
 	{'k', 0x2510},	/* upright corner */
 	{'l', 0x250c},	/* upleft corner */
 	{'m', 0x2514},	/* downleft corner */
 	{'n', 0x253c},	/* cross */
-	{'q', 0x2500},	/* horizontal line */
+	{'o', 0x23ba},  /* scan line 1/9 */
+	{'p', 0x23bb},  /* scan line 3/9 */
+	{'q', 0x2500},	/* horizontal line (also scan line 5/9) */
+	{'r', 0x23bc},  /* scan line 7/9 */
+	{'s', 0x23bd},  /* scan line 9/9 */
 	{'t', 0x251c},	/* left t */
 	{'u', 0x2524},	/* right t */
 	{'v', 0x252c},	/* down t */
 	{'w', 0x2534},	/* up t */
 	{'x', 0x2502},	/* vertical line */
-	{127, 0x00b7},	/* bullet */
+	{'y', 0x2264},  /* <= */
+	{'z', 0x2265},  /* >= */
+	{'{', 0x03c0},  /* pi */
+	{'|', 0x2260},  /* not equal */
+	{'}', 0x00a3},  /* pound currency sign */
+	{'~', 0x00b7},	/* bullet */
 };
 /* United Kingdom.  VT100 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map _vte_iso2022_map_A[] = {
@@ -80,9 +96,9 @@ static const struct _vte_iso2022_map _vte_iso2022_map_4[] = {
 	{'@',  GDK_threequarters},
 	{'[',  GDK_ydiaeresis},
 	{'\\', GDK_onehalf},
-	{']',  GDK_bar},
+	{']',  GDK_bar}, /* FIXME? not in XTerm 170 */
 	{'{',  GDK_diaeresis},
-	{'|',  GDK_f},
+	{'|',  0x192}, /* f with hook (florin) */ /* FIXME? not in XTerm 170 */
 	{'}',  GDK_onequarter},
 	{'~',  GDK_acute}
 };
@@ -201,7 +217,7 @@ static const struct _vte_iso2022_map _vte_iso2022_map_equal[] = {
 };
 /* Japanese.  JIS X 0201-1976 ("Roman" set), per RFC 1468/2237. */
 static const struct _vte_iso2022_map _vte_iso2022_map_J[] = {
-	{'\\', GDK_overline},
+	{'\\', 0x203e},
 	{'~',  GDK_yen},
 };
 /* Japanese.  JIS X 0208-1978, per RFC 1468/2237. */
@@ -320,6 +336,8 @@ _vte_iso2022_map_get(gunichar mapname)
 			ret = _vte_iso2022_map_init(_vte_iso2022_map_A,
 						    G_N_ELEMENTS(_vte_iso2022_map_A));
 			break;
+		case '1':
+		case '2':
 		case 'B':
 			ret = _vte_iso2022_map_init(_vte_iso2022_map_B,
 						    G_N_ELEMENTS(_vte_iso2022_map_B));
